<a id="plugins.aea-ledger-solana.aea_ledger_solana.utils"></a>

# plugins.aea-ledger-solana.aea`_`ledger`_`solana.utils

Utility functions for the Solana ledger.

<a id="plugins.aea-ledger-solana.aea_ledger_solana.utils.pako_inflate"></a>

#### pako`_`inflate

```python
def pako_inflate(data: Any) -> bytes
```

Decompress data using pako inflate. https://stackoverflow.com/questions/46351275/using-pako-deflate-with-python.

